package net.sourceforge.floatapi;

import java.awt.Container;

/*
 * Version 1.0
 *
 * This Class is Open Source Code under LGPL License.
 *
 *  copyright by floatAPI project group
 * contact us over http://floatAPI.sourceforge.net
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 *
 * Date: 12.10.2003  Time: 14:04:45
 *
 */

/**
 * <code>Container</code>s implement <code>Dockable</code> to provide docking for <code>Floating</code> <code>Component</code>s.
 *
 */
public interface Dockable {
    /**
     * @return the <code>Container</code> which is the target for docking of <code>Floating</code> <code>Component</code>s
     */
    Container getDockTarget();

    /**
     * is called through the <code>FloatingHandler</code> if a floating-event for docking in this <code>Dockable</code> is suggested
     * or has passed by.
     *
     * @see Dockable#updateDockGesture(boolean)
     * @param arriving true if, false if not
     */
    void updateDockGesture(boolean arriving);

    /**
     * determines if docking of the given <code>Floating</code> is possible on this <code>JDocker</code>.
     *
     * @see Dockable#isDockable(Floating)
     * @param floating which requests to be docked
     * @return true if docking of floating is possible, false if not
     */
    boolean isDockable(Floating floating);

    /**
     * @return the currently docked <code>Floating</code> or null, if vacant.
     */
    Floating getDocked();

    /**
     * fulfill the actual act of docking floating in this <code>Dockable</code>
     *
     * @param floating to dock in this
     */
    void dock(Floating floating);
    
	/**
	 * fulfill the actual act of undocking floating from this <code>Dockable</code>.
	 * 
	 * Usually, if this <code>Dockable</code> is only used for floating, this means
	 * setting the top level <code>Window</code> invisible and removing <code>floating.getFloatingComponent()</code>
	 * from the dockTarget.  
	 * The top level <code>Window</code> can be obtained through
	 * <code>FloatingHandler.getTop(getDockTarget())<code>.
	 *
	 * @param floating to undock from this
	 */
	void undock(Floating floating);
}