package net.sourceforge.floatapi;

import java.awt.Component;

/*
 * Version 1.0
 *
 * This Class is Open Source Code under LGPL License.
 *
 *  copyright by floatAPI project group
 * contact us over http://floatAPI.sourceforge.net
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 *
 * Date: 12.10.2003  Time: 14:05:23
 *
 */

/**
 * <code>Floating</code> is implemented by <code>Component</code>s using the floating mechanism.
 *
 */
public interface Floating {
    /**
     * returns the actual <code>Component</code> which is to be made floating.
     * @return the actual <code>Component</code> which is to be made floating.
     */
    Component getFloatingComponent();

    /**
     * returns a <code>String</code> to identify the type of this <code>Floating</code> by which the
     *         <code>Dockable</code> may decide if docking is acceptable.
     * @return a <code>String</code> to identify the type of this <code>Floating</code> by which the
     *         <code>Dockable</code> may decide if docking is acceptables
     */
    String getFloatingType();

    /**
     * returns a <code>Dockable</code> to use for floating.
     * 
     * This method is only to be called through {@link FloatingHandler#floatTo(Floating,Point)}.
     * The <code>Dockable</code> can be an attribute only belonging to the 
     * <code>Floating</code> object or a (newly created) object used by several <code>Floating</code>s. 
     * @return a <code>Dockable</code> to use for floating.
     */
    Dockable getFloater();

    /**
     * returns an <code>Array</code> of <code>Component</code>s which will be registered by the {@link FloatingHandler}
     *         as mouse triggers for floating gestures.
     * @return an <code>Array</code> of <code>Component</code>s which will be registered by the {@link FloatingHandler}
     *         as mouse triggers for floating gestures.
     */
    Component[] getFloatingTriggers();

    /**
     * returns the current <code>Dockable</code> last set with {@link #setCurrentDock(Dockable)}.
     * @return the current <code>Dockable</code> last set with {@link #setCurrentDock(Dockable)}.
     */
    Dockable getCurrentDock();

    /**
     * set the current <code>Dockable</code> which this <code>Floating</code> is docked in.
     * @param destination this <code>Floating</code> is docked in.
     */
    void setCurrentDock(Dockable destination);
}