package net.sourceforge.floatapi;

import java.awt.BorderLayout;
import java.awt.Component;

import javax.swing.JFrame;
import javax.swing.JPanel;



/*
 * Version 1.0
 *
 * This Class is Open Source Code under LGPL License.
 *
 *  copyright by floatAPI project group
 * contact us over http://floatAPI.sourceforge.net
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 *
 * Date: 12.10.2003  Time: 14:05:23
 *
 */

/**
 * <code>JFloater</code> is a convenience <code>JPanel</code> implementing <code>Floating</code>.
 *
 * It implements <code>Floating</code> as a <code>JPanel</code> and may be used for further added inside
 * <code>JComponent</code>s. Furthermore it allows the setting of floating type by which <code>Dockable</code>s can
 * determine if they want to allow docking. A floater <code>Dockable</code> can either be defined construction or a
 * default implementation for a floater can be created. The default type for a <code>JFloater</code> is "default".
 */

public class JFloater extends JPanel implements Floating {
    Dockable floater;
    String type="default";

    Dockable currentDock;

    /**
    * constructs a <code>JFloater</code> and a <code>floater</code> created in the {@link #createFloater()} method.
    */
    public JFloater(){
        this(null);
    }

    /**
     * constructs a <code>JFloater</code> with the given <code>floater</code>, or <code>null</code> if
     * the <code>floater</code> is to be create in the {@link #createFloater()} method.
     *
     * @param floater <code>Dockable</code> to use during floating
     */
    public JFloater(Dockable floater){
        if (floater!=null){
            this.floater=floater;
        } else{
            this.floater=createFloater();
        }
    }

    /**
     * defines the type of <code>Floating</code>.
     *
     * <code>Dockable</code>s can decide by {@link Floating#getFloatingType()} if they allow docking in
     * @param type to be defined
     */
    public void setFloatingType(String type){
        this.type=type;
    }

    /** convenience method to determin if this <code>JFloater</code> is currently floating
     *
     * @return true if the own floater is the currentDock
     */
    public boolean isFloating(){
        return (floater == currentDock);
    }

    /**
    * override to create different <code>Dockable</code>s when floating (or use constructor {@link #JFloater(Dockable)})
    *
    * @return the <code>Dockable</code> to use during floating (a <code>JFrame</code> with floatingType+" floating" as title)
    */
    public Dockable createFloater(){
        JFrame fl=new JFrame(type+" floating");
        fl.getContentPane().setLayout(new BorderLayout());
        JDocker dock=new JDocker(true);
        fl.getContentPane().add(dock,BorderLayout.CENTER);
        return dock;

    }

    /**
     * @see Floating#getFloater()
     * @return the <code>Dockable</code> to use during floating
     */
    public Dockable getFloater(){
        return floater;
    }

    /**
     * @see Floating#getCurrentDock()
     * @return the currentDock
     */
    public Dockable getCurrentDock(){
        return currentDock;
    }

    /**
     * @see Floating#setCurrentDock(Dockable)
     * @param destination to set as currentDock
     */
    public void setCurrentDock(Dockable destination) {
        currentDock=destination;
    }

    /**
     * override to define other <code>Component</code>s (than just <code>this</code>) to be triggers for floating events
     *
     * @return an <code>Array</code> of <code>Component</code>s which will be registered by the {@link FloatingHandler} as triggers for floating events
     */
    public Component[] getFloatingTriggers(){
        Component[] cs=new Component[1];
        cs[0]=this;
        return cs;
    }

    /**
     * @see Floating#getFloatingComponent()
     * @return <code>this</code>
     */
    public Component getFloatingComponent(){
        return this;
    }

    /**
     * @see Floating#getFloatingType()
     * @return a String type to identify the type of Floating
     */
    public String getFloatingType(){
        return type;
    }
}